@@ -1,10 +1,13 @@
 package Dist::Zilla::Plugin::MAXMIND::Contributors;
-$Dist::Zilla::Plugin::MAXMIND::Contributors::VERSION = '0.07';
+
 use v5.10;
 
 use strict;
 use warnings;
 use autodie;
+use namespace::autoclean;
+
+our $VERSION = '0.08';
 
 use Dist::Zilla::File::InMemory;
 
