@@ -1,10 +1,13 @@
 package Dist::Zilla::Plugin::MAXMIND::License;
-$Dist::Zilla::Plugin::MAXMIND::License::VERSION = '0.07';
+
 use v5.10;
 
 use strict;
 use warnings;
 use autodie;
+use namespace::autoclean;
+
+our $VERSION = '0.08';
 
 use Module::Runtime qw( use_module );
 use String::RewritePrefix;
